﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;
using System.Diagnostics;
using Infragistics.UltraChart.Core.Primitives;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        private DataTable dt;
        private ScatterChartAppearance sca1;
        private ScatterChartAppearance sca2;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            
            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            dt = new DataTable();
            dt.Columns.Add("Month", typeof(DateTime));
            dt.Columns.Add("MonthLab", typeof(string));
            dt.Columns.Add("2010", typeof(double));
            dt.Columns.Add("2011", typeof(double));
            dt.Columns.Add("2012", typeof(double));

            dt.Rows.Add(DateTime.Today, "Jul", 10, 50, 30);
            dt.Rows.Add(DateTime.Today.AddMonths(1), "Aug", 20, 35, 20);
            dt.Rows.Add(DateTime.Today.AddMonths(2), "Sep", 40, 60, 50);
            dt.Rows.Add(DateTime.Today.AddMonths(3), "Nov", 15, 40, 30);
            dt.Rows.Add(DateTime.Today.AddMonths(4), "Dec", 20, 35, null);
            dt.Rows.Add(DateTime.Today.AddMonths(5), "Jan", 20, 25, null);
            dt.Rows.Add(DateTime.Today.AddMonths(6), "Feb", 10, 50, null);
            dt.Rows.Add(DateTime.Today.AddMonths(7), "Mar", 20, 35, null);
            dt.Rows.Add(DateTime.Today.AddMonths(8), "Apr", 40, 60, null);
            dt.Rows.Add(DateTime.Today.AddMonths(9), "May", 15, 40, null);
            dt.Rows.Add(DateTime.Today.AddMonths(10), "Jun", 20, 35, null);
            dt.Rows.Add(DateTime.Today.AddMonths(11), "Jul", 20, 25, null);


            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.Extent = 120;
            axisX.DataType = AxisDataType.Time;
            axisX.NumericAxisType = NumericAxisType.Linear;
            axisX.LineColor = Color.Blue;
            //axisX.ScrollScale.Visible = true;

            axisX.Labels.Visible = true;
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX.Labels.ItemFormat = AxisItemLabelFormat.ItemLabel;
            axisX.TickmarkInterval = 1;
            axisX.SetLabelAxisType = SetLabelAxisType.DateData;
            area.Axes.Add(axisX);

            AxisItem axisY = new AxisItem();
            axisY.Extent = 20;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.LineColor = Color.Blue;
            area.Axes.Add(axisY);


            NumericTimeSeries series1 = new NumericTimeSeries();
            series1.Label = "Year 2010";
            series1.DataBind(dt, "Month", "2010", "MonthLab");
            series1.PEs.Add(new PaintElement(Color.Blue));

            NumericTimeSeries series2 = new NumericTimeSeries();
            series2.Label = "Year 2011";
            series2.DataBind(dt, "Month", "2011", "MonthLab");
            series2.PEs.Add(new PaintElement(Color.Red));

            NumericTimeSeries series3 = new NumericTimeSeries();
            series3.Label = "Year 2012";
            series3.DataBind(dt, "Month", "2012", "MonthLab");
            series3.PEs.Add(new PaintElement(Color.Yellow));


            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ScatterChart;
            myColumnLayer.ChartArea = area;
            myColumnLayer.Series.Add(series1);
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            ultraChart1.CompositeChart.Series.Add(series1);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);


            ChartLayerAppearance myColumnLayer2 = new ChartLayerAppearance();
            myColumnLayer2.ChartType = ChartType.ScatterChart;
            myColumnLayer2.ChartArea = area;
            myColumnLayer2.AxisX = axisX;
            myColumnLayer2.AxisY = axisY;
            myColumnLayer2.Series.Add(series2);
            ultraChart1.CompositeChart.Series.Add(series2);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer2);

            ChartLayerAppearance myColumnLayer3 = new ChartLayerAppearance();
            myColumnLayer3.ChartType = ChartType.ScatterChart;
            myColumnLayer3.ChartArea = area;
            myColumnLayer3.AxisX = axisX;
            myColumnLayer3.AxisY = axisY;
            myColumnLayer3.Series.Add(series3);
            ultraChart1.CompositeChart.Series.Add(series3);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer3);


            sca1 = new ScatterChartAppearance();
            sca1.ConnectWithLines = true;
            sca1.Icon = SymbolIcon.Circle;
            sca1.IconSize = SymbolIconSize.Large;// Small;
            myColumnLayer.ChartTypeAppearance = sca1;

            sca2 = new ScatterChartAppearance();
            sca2.ConnectWithLines = true;
            sca2.Icon = SymbolIcon.Triangle;
            sca2.IconSize = SymbolIconSize.Large;// Small;
            myColumnLayer2.ChartTypeAppearance = sca2;
            myColumnLayer3.ChartTypeAppearance = sca2;

            ultraComboEditor1.Items.Add(SymbolIcon.Circle);
            ultraComboEditor1.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor1.Items.Add(SymbolIcon.Plus);
            ultraComboEditor1.Items.Add(SymbolIcon.Square);
            ultraComboEditor1.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor1.Value = SymbolIcon.Circle;

            ultraComboEditor2.Items.Add(SymbolIcon.Circle);
            ultraComboEditor2.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor2.Items.Add(SymbolIcon.Plus);
            ultraComboEditor2.Items.Add(SymbolIcon.Square);
            ultraComboEditor2.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor2.Value = SymbolIcon.Triangle;

            CompositeLegend myLegend = new CompositeLegend();
            myLegend.ChartLayers.Add(myColumnLayer);
            myLegend.ChartLayers.Add(myColumnLayer2);
            myLegend.ChartLayers.Add(myColumnLayer3);
            myLegend.ChartLayers[1].LegendItem = LegendItemType.Auto;
            myLegend.Bounds = new Rectangle(6, 2, 15, 12);
            myLegend.BoundsMeasureType = MeasureType.Percentage;
            myLegend.PE.ElementType = PaintElementType.Gradient;
            myLegend.PE.FillGradientStyle = GradientStyle.ForwardDiagonal;
            myLegend.PE.Fill = Color.CornflowerBlue;
            myLegend.PE.FillStopColor = Color.Transparent;
            myLegend.Border.CornerRadius = 10;
            myLegend.Border.Thickness = 1;

            this.ultraChart1.CompositeChart.Legends.Add(myLegend);

        }

        private void ultraButton3_Click(object sender, EventArgs e)
        {
            ultraChart1.SaveTo(@"..\\..\\Test.bmp", System.Drawing.Imaging.ImageFormat.Bmp);
            Process.Start("..\\..\\Test.bmp");
        }

        private void ultraComboEditor1_ValueChanged(object sender, EventArgs e)
        {
            sca1.Icon = (SymbolIcon)ultraComboEditor1.Value;
        }

        private void ultraComboEditor2_ValueChanged(object sender, EventArgs e)
        {
            sca2.Icon = (SymbolIcon)ultraComboEditor2.Value;
        }


    }
}